#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 named-text
version:              1.2.2.0
visibility:           public
id:                   named-text-1.2.2.0-8nfHPdi1GwC3J3G8J4VGUd
key:                  named-text-1.2.2.0-8nfHPdi1GwC3J3G8J4VGUd
license:              ISC
copyright:            Galois Inc, 2023
maintainer:           kquick@galois.com
author:               Kevin Quick
synopsis:
    A parameterized named text type and associated functionality.

description:

    A plain String or Text is dangerous because it can be arbitrarily combined,
    converted, emitted, and updated without consideration of the validity and
    applicability of the contents and the usage scenario.

    This module provides a Named type wrapper around Text which has two
    additional type parameters: one which indicates what the content of the Text
    represents, and one which indicates the style of the name.

    There are additionally functions and classes which allow conversions and
    transformations between names with different styles and types (or disallow them
    where appropriate).

    The core intent of this library is that the Named is used instead of a raw
    String or Text to provide type-level tracking and safety.

category:             Data
abi:                  3af3c648490c5878b5dddcf46ade7422
exposed:              True
exposed-modules:      Data.Name Data.Name.JSON
hidden-modules:       Data.Name.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/named-text-1.2.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/named-text-1.2.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/named-text-1.2.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-named-text
hs-libraries:         HSnamed-text-1.2.2.0-8nfHPdi1GwC3J3G8J4VGUd
depends:
    aeson-2.2.2.0-D5UyU4s17IF6uKIJTSur7o base-4.18.2.1 deepseq-1.4.8.1
    hashable-1.4.7.0-4qZi9v5WFMZ3p1WVFpevAr
    prettyprinter-1.7.1-4EZkWc5tq0yFCEPbAPD9Qw
    sayable-1.2.6.0-b0qpKJoCa57hZH8gmdVcX text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-named-text/html/named-text.haddock
haddock-html:         /usr/share/doc/haskell-named-text/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

